_**by Edgar Allan Poe**  
(published 1833)_

    

OF my country and of my family I have little to say. Ill usage and length of years have driven me from the one, and estranged me from the other. Hereditary wealth afforded me an education of no common order, and a contemplative turn of mind enabled me to methodize the stores which early study very diligently garnered up. Beyond all things the works of the German moralists gave me great delight; not from any ill-advised admiration of their eloquent madness, but from the ease with which my habits of rigid thought enabled me to detect their falsities. I have often been reproached with the aridity of my genius --a deficiency of imagination has been imputed to me as a crime --and the Pyrrhonism of my opinions has at all times rendered me notorious. Indeed a strong relish for physical philosophy has, I fear, tinctured my mind with a very common error of this age --I mean the habit of referring occurrences, even the least susceptible of such reference, to the principles of that science. Upon the whole, no person could be less liable than myself to be led away from the severe precincts of truth by the ignes fatui of superstition. I have thought proper to premise thus much lest the incredible tale I have to tell should be considered rather the raving of a crude imagination, than the positive experience of a mind to which the reveries of fancy have been a dead letter and a nullity.  
  
    After many years spent in foreign travel, I sailed in the year 18-- , from the port of Batavia, in the rich and populous island of Java, on a voyage to the Archipelago of the Sunda islands. I went as passenger --having no other inducement than a kind of nervous restlessness which haunted me like a fiend.  
  
    Our vessel was a beautiful ship of about four hundred tons, copper-fastened, and built at Bombay of Malabar teak. She was freighted with cotton-wool and oil, from the Lachadive islands. We had also on board coir, jaggeree, ghee, cocoa-nuts, and a few cases of opium. The stowage was clumsily done, and the vessel consequently crank.  
  
    We got under way with a mere breath of wind, and for many days stood along the eastern coast of Java, without any other incident to beguile the monotony of our course than the occasional meeting with some of the small grabs of the Archipelago to which we were bound. One evening, leaning over the taffrail, I observed a very singular, isolated cloud, to the N. W. It was remarkable, as well for its color, as from its being the first we had seen since our departure from Batavia. I watched it attentively until sunset, when it spread all at once to the eastward and westward, girting in the horizon with a narrow strip of vapor, and looking like a long line of low beach. My notice was soon afterwards attracted by the duskyred appearance of the moon, and the peculiar character of the sea. The latter was undergoing a rapid change, and the water seemed more than usually transparent. Although I could distinctly see the bottom, yet, heaving the lead, I found the ship in fifteen fathoms. The air now became intolerably hot, and was loaded with spiral exhalations similar to those arising from heated iron. As night came on, every breath of wind died away, and a more entire calm it is impossible to conceive. The flame of a candle burned upon the poop without the least perceptible motion, and a long hair, held between the finger and thumb, hung without the possibility of detecting a vibration. However, as the captain said he could perceive no indication of danger, and as we were drifting in bodily to shore, he ordered the sails to be furled, and the anchor let go. No watch was set, and the crew, consisting principally of Malays, stretched themselves deliberately upon deck. I went below --not without a full presentiment of evil. Indeed every appearance warranted me in apprehending a Simoom. I told the captain my fears --but he paid no attention to what I said, and left me without deigning to give a reply. My uneasiness, however, prevented me from sleeping, and about midnight I went upon deck. As I placed my foot upon the upper step of the companion-ladder, I was startled with a loud, humming noise, like that occasioned by the rapid revolution of a mill-wheel, and before I could ascertain its meaning, I found the ship quivering to its centre. In the next instant, a wilderness of foam hurled us upon our beam-ends, and, rushing over us fore and aft, swept the entire decks from stem to stern.  
  
    The extreme fury of the blast proved in a great measure the salvation of the ship. Although completely water-logged, yet, as all her masts had gone by the board, she rose, after a minute, heavily from the sea, and, staggering awhile beneath the immense pressure of the tempest, finally righted.  
  
    By what miracle I escaped destruction, it is impossible to say. Stunned by the shock of the water, I found myself, upon recovery, jammed in between the stern-post and rudder. With great difficulty I gained my feet, and looking dizzily around, was, at first, struck with the idea of our being among breakers, so terrific beyond the wildest imagination was the whirlpool of mountainous and foaming ocean within which we were engulfed. After a while, I heard the voice of an old Swede, who had shipped with us at the moment of our leaving port. I hallooed to him with all my strength, and presently he came reeling aft. We soon discovered that we were the sole survivors of the accident. All on deck, with the exception of ourselves, had been swept overboard, and the captain and mates must have perished as they slept, for the cabins were deluged with water. Without assistance, we could expect to do little for the security of the ship, and our exertions were at first paralyzed by the momentary expectation of going down. Our cable had, of course, parted like pack-thread, at the first breath of the hurricane, or we should have been instantaneously overwhelmed. We scudded with frightful velocity before the sea, and the water made clear breaches over us. The frame-work of our stern was shattered excessively, and, in almost every respect, we had received considerable injury --but to our extreme joy we found the pumps unchoked, and that we had made no great shifting of our ballast. The main fury of the Simoom had already blown over, and we apprehended little danger from the violence of the wind --but we looked forward to its total cessation with dismay, well believing, that, in our shattered condition, we should inevitably perish in the tremendous swell which would ensue. But this very just apprehension seemed by no means likely to be soon verified. For five entire days and nights --during which our only subsistence was a small quantity of jaggeree, procured with great difficulty from the forecastle --the hulk flew at a rate defying computation, before rapidly succeeding flaws of wind, which, without equalling the first violence of the Simoom, were still more terrific than any tempest I had before encountered. Our course for the first four days was, with trifling variations, S. E. and by South; and we must have run down the coast of New Holland. On the fifth day the cold became extreme, although the wind had hauled round a point more to the northward. The sun arose with a sickly yellow lustre, and clambered a very few degrees above the horizon --emitting no decisive light. There were no clouds whatever apparent, yet the wind was upon the increase, and blew with a fitful and unsteady fury. About noon, as nearly as we could guess, our attention was again arrested by the appearance of the sun. It gave out no light, properly so called, but a dull and sullen glow unaccompanied by any ray. Just before sinking within the turgid sea its central fires suddenly went out, as if hurriedly extinguished by some unaccountable power. It was a dim, silver-like rim, alone, as it rushed down the unfathomable ocean.  
  
    We waited in vain for the arrival of the sixth day --that day to me has not arrived --to the Swede, never did arrive. Thenceforward we were enshrouded in pitchy darkness, so that we could not have seen an object at twenty paces from the ship. Eternal night continued to envelop us, all unrelieved by the phosphoric sea-brilliancy to which we had been accustomed in the tropics. We observed too, that, although the tempest continued to rage with unabated violence, there was no longer to be discovered the usual appearance of surf, or foam, which had hitherto attended us. All around was horror, and thick gloom, and a black sweltering desert of ebony. Superstitious terror crept by degrees into the spirit of the old Swede, and my own soul was wrapped up in silent wonder. We neglected all care of the ship, as worse than useless, and securing ourselves as well as possible to the stump of the mizen-mast, looked out bitterly into the world of ocean. We had no means of calculating time, nor could we form any guess of our situation. We were, however, well aware of having made farther to the southward than any previous navigators, and felt extreme amazement at not meeting with the usual impediments of ice. In the meantime every moment threatened to be our last --every mountainous billow hurried to overwhelm us. The swell surpassed anything I had imagined possible, and that we were not instantly buried is a miracle. My companion spoke of the lightness of our cargo, and reminded me of the excellent qualities of our ship --but I could not help feeling the utter hopelessness of hope itself, and prepared myself gloomily for that death which I thought nothing could defer beyond an hour, as, with every knot of way the ship made, the swelling of the black stupendous seas became more dismally appalling. At times we gasped for breath at an elevation beyond the Albatross --at times became dizzy with the velocity of our descent into some watery hell, where the air grew stagnant, and no sound disturbed the slumbers of the Kraken.  
  
    We were at the bottom of one of these abysses, when a quick scream from my companion broke fearfully upon the night. "See! see!" --cried he, shrieking in my ears, -- "Almighty God! see! see!" As he spoke, I became aware of a dull, sullen glare of red light which streamed down the sides of the vast chasm where we lay, and threw a fitful brilliancy upon our deck. Casting my eyes upwards, I beheld a spectacle which froze the current of my blood. At a terrific height directly above us, and upon the very verge of the precipitous descent, hovered a gigantic ship of nearly four thousand tons. Although upreared upon the summit of a wave of more than a hundred times her own altitude, her apparent size still exceeded that of any ship of the line or East Indiaman in existence. Her huge hull was of a deep dingy black, unrelieved by any of the customary carvings of a ship. A single row of brass cannon protruded from her open ports, and dashed off from their polished surfaces the fires of innumerable battle-lanterns, which swung to and fro about her rigging. But what mainly inspired us with horror and astonishment, was that she bore up under a press of sail in the very teeth of that supernatural sea, and of that ungovernable hurricane. When we first discovered her, her stupendous bows were alone to be seen, as she rose up, like a demon of the deep, slowly from the dim and horrible gulf beyond her. For a moment of intense terror she paused upon the giddy pinnacle, as if in contemplation of her own sublimity, then trembled and tottered, and --came down.  
  
    At this instant, I know not what sudden self-possession came over my spirit. Staggering as far aft as I could, I awaited fearlessly the ruin that was to overwhelm. Our own vessel was at length ceasing from her struggles, and sinking with her head to the sea. The shock of the descending mass struck her, consequently, in that portion of her frame which was already under water, and the inevitable result was to hurl me with irresistible violence upon the rigging of the stranger.  
  
    As I fell, the ship hove in stays, and went about, and to the confusion ensuing I attributed my escape from the notice of the crew. With little difficulty I made my way unperceived to the main hatchway, which was partially open, and soon found an opportunity of secreting myself in the hold. Why I did so I can hardly tell. A nameless and indefinite sense of awe, which at first sight of the navigators of the ship had taken hold of my mind, was perhaps the principle of my concealment. I was unwilling to trust myself with a race of people who had offered, to the cursory glance I had taken, so many points of vague novelty, doubt, and apprehension. I therefore thought proper to contrive a hiding-place in the hold. This I did by removing a small portion of the shifting-boards in such a manner as to afford me a convenient retreat between the huge timbers of the ship.  
  
    I had scarcely completed my work, when a footstep in the hold forced me to make use of it. A man passed by my place of concealment with a feeble and unsteady gait. I could not see his face, but had an opportunity of observing his general appearance. There was about it an evidence of great age and infirmity. His knees tottered beneath a load of years, and his entire frame quivered under the burthen. He muttered to himself, in a low broken tone, some words of a language which I could not understand, and groped in a corner among a pile of singular-looking instruments, and decayed charts of navigation. His manner was a wild mixture of the peevishness of second childhood, and the solemn dignity of a god. He at length went on deck, and I saw him no more.  
  
                                           *      *      *      *      *      *  
  
    A feeling, for which I have no name, has taken possession of my soul -- a sensation which will admit of no analysis, to which the lessons of by-gone time are inadequate, and for which I fear futurity itself will offer me no key. To a mind constituted like my own the latter consideration is an evil. I shall never, -- I know that I shall never -- be satisfied with regard to the nature of my conceptions. Yet it is not wonderful that these conceptions are indefinite, since they have their origin in sources so utterly novel. A new sense, a new entity is added to my soul.  
  
    It is long since I first trod the deck of this terrible ship, and the rays of my destiny are, I think, gathering to a focus. Incomprehensible men! Wrapped up in meditations of a kind which I cannot divine, they pass me by unnoticed. Concealment is utter folly on my part, for the people will not see. It was but just now that I passed directly before the eyes of the mate, -- it was no long while ago that I ventured into the captain's own private cabin, and took thence the materials with which I write, and have written. I shall from time to time continue this journal. It is true that I may not find an opportunity of transmitting it to the world, but I will not fail to make the endeavor. At the last moment I will enclose the MS. in a bottle, and cast it within the sea.  
  
    An incident has occurred which has given me new room for meditation. Are such things the operations of ungoverned Chance? I had ventured upon deck and thrown myself down, without attracting any notice, among a pile of ratlin-stuff and old sails in the bottom of the yawl. While musing upon the singularity of my fate, I unwittingly daubed with a tar-brush the edges of a neatly-folded studding-sail which lay near me on a barrel. The studding-sail is now bent upon the ship, and the thoughtless touches of the brush are spread out into the word DISCOVERY.  
  
    I have made many observations lately upon the structure of the vessel. Although well armed, she is not, I think, a ship of war. Her rigging, build, and general equipment, all negative a supposition of this kind. What she is not I can easily perceive, what she is I fear it is impossible to say. I know not how it is, but in scrutinizing her strange model and singular cast of spars, her huge size and overgrown suits of canvass, her severely simple bow and antiquated stern, there will occasionally flash across my mind a sensation of familiar things, and there is always mixed up with such indistinct shadows of recollection, an unaccountable memory of old foreign chronicles and ages long ago.  
  
    I have been looking at the timbers of the ship. She is built of a material to which I am a stranger. There is a peculiar character about the wood which strikes me as rendering it unfit for the purpose to which it has been applied. I mean its extreme porousness, considered independently of the wormeaten condition which is a consequence of navigation in these seas, and apart from the rottenness attendant upon age. It will appear perhaps an observation somewhat over-curious, but this wood has every characteristic of Spanish oak, _if Spanish oak were distended or swelled by any unnatural means_.  
  
    In reading the above sentence a curious apothegm of an old weather-beaten Dutch navigator comes full upon my recollection. "It is as sure," he was wont to say, when any doubt was entertained of his veracity, "as sure as there is a sea where the ship itself will grow in bulk like the living body of the seaman."  
  
    About an hour ago, I made bold to thrust myself among a group of the crew. They paid me no manner of attention, and, although I stood in the very midst of them all, seemed utterly unconscious of my presence. Like the one I had at first seen in the hold, they all bore about them the marks of a hoary old age. Their knees trembled with infirmity, their shoulders were bent double with decrepitude, their shrivelled skins rattled in the wind, their voices were low, tremulous, and broken, their eyes glistened with the rheum of years, and their gray hairs streamed terribly in the tempest. Around them on every part of the deck lay scattered mathematical instruments of the most quaint and obsolete construction.  
  
    I mentioned some time ago the bending of a studding-sail. From that period the ship, being thrown dead off the wind, has held her terrific course due south, with every rag of canvass packed upon her from her trucks to her lower-studding-sail booms, and rolling every moment her top-gallant yard-arms into the most appalling hell of water which it can enter into the mind of man to imagine. I have just left the deck, where I find it impossible to maintain a footing, although the crew seem to experience little inconvenience. It appears to me a miracle of miracles that our enormous bulk is not buried up at once and forever. We are surely doomed to hover continually upon the brink of Eternity, without taking a final plunge into the abyss. From billows a thousand times more stupendous than any I have ever seen, we glide away with the facility of the arrowy sea-gull; and the colossal waters rear their heads above us like demons of the deep, but like demons confined to simple threats and forbidden to destroy. I am led to attribute these frequent escapes to the only natural cause which can account for such effect. I must suppose the ship to be within the influence of some strong current, or impetuous under-tow.  
  
    I have seen the captain face to face, and in his own cabin -- but, as I expected, he paid me no attention. Although in his appearance there is, to a casual observer, nothing which might bespeak him more or less than man --still a feeling of irrepressible reverence and awe mingled with the sensation of wonder with which I regarded him. In stature he is nearly my own height, that is, about five feet eight inches. He is of a well-knit and compact frame of body, neither robust nor remarkably otherwise. But it is the singularity of the expression which reigns upon the face, it is the intense, the wonderful, the thrilling evidence of old age so utter, so extreme, which excites within my spirit a sense --a sentiment ineffable. His forehead, although little wrinkled, seems to bear upon it the stamp of a myriad of years. His gray hairs are records of the past, and his grayer eyes are sybils of the future. The cabin floor was thickly strewn with strange, iron-clasped folios, and mouldering instruments of science, and obsolete long-forgotten charts. His head was bowed down upon his hands, and he pored with a fiery unquiet eye over a paper which I took to be a commission, and which, at all events, bore the signature of a monarch. He muttered to himself, as did the first seaman whom I saw in the hold, some low peevish syllables of a foreign tongue, and although the speaker was close at my elbow, yet his voice seemed to reach my ears from the distance of a mile.  
  
    The ship and all in it are imbued with the spirit of Eld. The crew glide to and fro like the ghosts of buried centuries, their eyes have an eager and uneasy meaning, and when their figures fall athwart my path in the wild glare of the battle-latterns, I feel as I have never felt before, although I have been all my life a dealer in antiquities, and have imbibed the shadows of fallen columns at Balbec, and Tadmor, and Persepolis, until my very soul has become a ruin.  
  
    When I look around me I feel ashamed of my former apprehensions. If I trembled at the blast which has hitherto attended us, shall I not stand aghast at a warring of wind and ocean, to convey any idea of which the words tornado and simoom are trivial and ineffective! All in the immediate vicinity of the ship is the blackness of eternal night, and a chaos of foamless water; but, about a league on either side of us, may be seen, indistinctly and at intervals, stupendous ramparts of ice, towering away into the desolate sky, and looking like the walls of the universe.  
  
    As I imagined, the ship proves to be in a current; if that appellation can properly be given to a tide which, howling and shrieking by the white ice, thunders on to the southward with a velocity like the headlong dashing of a cataract.  
  
    To conceive the horror of my sensations is, I presume, utterly impossible --yet a curiosity to penetrate the mysteries of these awful regions predominates even over my despair, and will reconcile me to the most hideous aspect of death. It is evident that we are hurrying onwards to some exciting knowledge --some never-to-be-imparted secret, whose attainment is destruction. Perhaps this current leads us to the southern pole itself --it must be confessed that a supposition apparently so wild has every probability in its favor.  
  
    The crew pace the deck with unquiet and tremulous step, but there is upon their countenances an expression more of the eagerness of hope than of the apathy of despair.  
  
    In the meantime the wind is still in our poop, and as we carry a crowd of canvass, the ship is at times lifted bodily from out the sea --Oh, horror upon horror! the ice opens suddenly to the right, and to the left, and we are whirling dizzily, in immense concentric circles, round and round the borders of a gigantic amphitheatre, the summit of whose walls is lost in the darkness and the distance. But little time will be left me to ponder upon my destiny --the circles rapidly grow small --we are plunging madly within the grasp of the whirlpool --and amid a roaring, and bellowing, and shrieking of ocean and of tempest, the ship is quivering, oh God! and --going down.